==> haskell-clientsession-0.9.1.2-166-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.1.2
visibility:           public
id:                   clientsession-0.9.1.2-ADMKzjb7uWiJRN94uUzdtw
key:                  clientsession-0.9.1.2-ADMKzjb7uWiJRN94uUzdtw
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  0046021d8d28bb9a25e6a0a31a9070b1
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-8.10.2/site-local/clientsession-0.9.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/clientsession-0.9.1.2
hs-libraries:         HSclientsession-0.9.1.2-ADMKzjb7uWiJRN94uUzdtw
depends:
    base-4.14.1.0 base64-bytestring-1.2.0.0-B6hMzATpkPd4ftnL7NOOue
    bytestring-0.10.10.0 cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cipher-aes-0.2.11-30ajZYkZ5rYE09s79JcV2w
    cprng-aes-0.6.1-K72SSJ9iDQk5I46D8oIc0Z
    crypto-api-0.13.3-3crMriq1Cru2GHNhVUzp6Y
    crypto-random-0.0.9-I9CYmoSKPwh7axGuXqTU9E directory-1.3.6.0
    entropy-0.4.1.6-9PryOfo5UGm2sncsbscV7i
    setenv-0.1.1.3-FjFLzlxhySgkTKHvS1WwL
    skein-1.0.9.4-KGrq5lF99x3ED3vg1qpdeF
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.2-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.1.2
visibility:           public
id:                   clientsession-0.9.1.2-2WvFkO9VrOmAFKFH95FNi1
key:                  clientsession-0.9.1.2-2WvFkO9VrOmAFKFH95FNi1
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  5f9e788f85b50433723801fb4bfc1007
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-8.10.2/site-local/clientsession-0.9.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/clientsession-0.9.1.2
hs-libraries:         HSclientsession-0.9.1.2-2WvFkO9VrOmAFKFH95FNi1
depends:
    base-4.14.1.0 base64-bytestring-1.2.0.0-QGUQVBvRt835GfxPBh70w
    bytestring-0.10.10.0 cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cipher-aes-0.2.11-30ajZYkZ5rYE09s79JcV2w
    cprng-aes-0.6.1-La8yv6Z5BLzHnPyOUKHsbF
    crypto-api-0.13.3-3crMriq1Cru2GHNhVUzp6Y
    crypto-random-0.0.9-41bXQxuS8M5L5tzoZK1O6D directory-1.3.6.0
    entropy-0.4.1.6-9PryOfo5UGm2sncsbscV7i
    setenv-0.1.1.3-FjFLzlxhySgkTKHvS1WwL
    skein-1.0.9.4-KGrq5lF99x3ED3vg1qpdeF
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
